@@ -10,6 +10,7 @@ from pulpcore.plugin.models import (
     Content,
     Remote,
     Repository,
+    RepositoryVersion,
     RepositoryVersionDistribution,
     Task,
 )
@@ -47,8 +48,6 @@ class Collection(BaseModel):
     namespace = models.CharField(max_length=64, editable=False)
     name = models.CharField(max_length=64, editable=False)
 
-    deprecated = models.BooleanField(default=False)
-
     class Meta:
         unique_together = ("namespace", "name")
 
@@ -118,7 +117,6 @@ class CollectionVersion(Content):
         version (models.CharField): The version of the collection.
         is_highest (models.BooleanField): Indicates that the version is the highest one
             in the collection.
-        certification (models.CharField): Enum with certification status.
 
     Relations:
 
@@ -128,12 +126,6 @@ class CollectionVersion(Content):
 
     TYPE = "collection_version"
 
-    CERTIFICATION_CHOICES = [
-        ("certified", "certified"),
-        ("not_certified", "not_certified"),
-        ("needs_review", "needs_review"),
-    ]
-
     # Data Fields
     authors = psql_fields.ArrayField(models.CharField(max_length=64), default=list, editable=False)
     contents = psql_fields.JSONField(default=list, editable=False)
@@ -147,12 +139,9 @@ class CollectionVersion(Content):
     name = models.CharField(max_length=64, editable=False)
     namespace = models.CharField(max_length=32, editable=False)
     repository = models.CharField(default="", blank=True, max_length=2000, editable=False)
-    version = models.CharField(max_length=32, editable=False)
+    version = models.CharField(max_length=128, editable=False)
 
     is_highest = models.BooleanField(editable=False, default=False)
-    certification = models.CharField(
-        max_length=13, choices=CERTIFICATION_CHOICES, default="needs_review"
-    )
 
     # Foreign Key Fields
     collection = models.ForeignKey(
@@ -172,19 +161,6 @@ class CollectionVersion(Content):
             namespace=self.namespace, name=self.name, version=self.version
         )
 
-    def save(self, *args, **kwargs):
-        """
-        Validates certification before save.
-
-        """
-        certification_choices = [value for key, value in self.CERTIFICATION_CHOICES]
-        if self.certification not in certification_choices:
-            raise ValueError(
-                "Invalid certification value: '{value}'".format(value=self.certification)
-            )
-
-        super().save(*args, **kwargs)
-
     class Meta:
         default_related_name = "%(app_label)s_%(model_name)s"
         unique_together = ("namespace", "name", "version")
@@ -251,13 +227,57 @@ class AnsibleRepository(Repository):
 
     TYPE = "ansible"
     CONTENT_TYPES = [Role, CollectionVersion]
-    REMOTE_TYEPES = [RoleRemote, CollectionRemote]
+    REMOTE_TYPES = [RoleRemote, CollectionRemote]
 
     class Meta:
         default_related_name = "%(app_label)s_%(model_name)s"
 
         permissions = (("modify_ansible_repo_content", "Can modify ansible repository content"),)
 
+    def finalize_new_version(self, new_version):
+        """
+        Finalize the incomplete RepositoryVersion with correct repository-level metadata.
+
+        `AnsibleCollectionDeprecated` objects may need to be created for the new
+        `RepositoryVersion`.
+
+        Args:
+            new_version (pulpcore.app.models.RepositoryVersion): The incomplete RepositoryVersion to
+                finalize.
+
+        """
+        deprecated_in_prev_version_qs = Collection.objects.filter(
+            ansiblecollectiondeprecated__repository_version=new_version.previous()
+        )
+        collection_versions_removed_pks = new_version.removed().values("pk")
+        deprecated_in_this_version = deprecated_in_prev_version_qs.exclude(
+            versions__in=collection_versions_removed_pks
+        )
+        to_deprecate = []
+        for collection_deprecated in deprecated_in_this_version:
+            to_deprecate.append(
+                AnsibleCollectionDeprecated(
+                    repository_version=new_version, collection=collection_deprecated
+                )
+            )
+
+        if to_deprecate:
+            AnsibleCollectionDeprecated.objects.bulk_create(to_deprecate, ignore_conflicts=True)
+
+
+class AnsibleCollectionDeprecated(BaseModel):
+    """
+    A model that represents if a Collection is `deprecated` for a given RepositoryVersion.
+    """
+
+    repository_version = models.ForeignKey(
+        RepositoryVersion, on_delete=models.CASCADE, related_name="collection_memberships"
+    )
+    collection = models.ForeignKey(Collection, on_delete=models.CASCADE)
+
+    class Meta:
+        unique_together = ("collection", "repository_version")
+
 
 class AnsibleDistribution(RepositoryVersionDistribution):
     """
