@@ -8,6 +8,7 @@ import tarfile
 from urllib.parse import urljoin, urlparse, urlunparse
 
 from django.db import transaction
+from django.db.models import Q
 from django.urls import reverse
 from galaxy_importer.collection import import_collection as process_collection
 from galaxy_importer.collection import CollectionFilename
@@ -35,7 +36,7 @@ from pulpcore.plugin.stages import (
     QueryExistingArtifacts,
     QueryExistingContents,
 )
-import semantic_version as semver
+from semantic_version import Version
 
 from pulp_ansible.app.constants import PAGE_SIZE
 from pulp_ansible.app.models import (
@@ -81,6 +82,23 @@ def sync(remote_pk, repository_pk, mirror):
     d_version = AnsibleDeclarativeVersion(first_stage, repository, mirror=mirror)
     d_version.create()
 
+    repo_version = repository.latest_version()
+    to_deprecate = []
+    if first_stage.deprecations:
+        collections_deprecate_true_qs = Collection.objects.filter(first_stage.deprecations)
+        for collection in collections_deprecate_true_qs:
+            to_deprecate.append(
+                AnsibleCollectionDeprecated(repository_version=repo_version, collection=collection)
+            )
+
+        AnsibleCollectionDeprecated.objects.bulk_create(to_deprecate, ignore_conflicts=True)
+
+    non_deprecated_qs = Collection.objects.exclude(first_stage.deprecations)
+    AnsibleCollectionDeprecated.objects.filter(
+        repository_version=repo_version,
+        collection__pk__in=non_deprecated_qs,
+    ).delete()
+
 
 def import_collection(
     temp_file_pk,
@@ -135,11 +153,11 @@ def import_collection(
             collection_version = create_collection_from_importer(importer_result)
 
     except ImporterError as exc:
-        log.info(f"Collection processing was not successfull: {exc}")
+        log.info(f"Collection processing was not successful: {exc}")
         temp_file.delete()
         raise
     except Exception as exc:
-        user_facing_logger.error(f"Collection processing was not successfull: {exc}")
+        user_facing_logger.error(f"Collection processing was not successful: {exc}")
         temp_file.delete()
         raise
 
@@ -220,7 +238,7 @@ def _update_highest_version(collection_version):
     if not last_highest:
         collection_version.is_highest = True
         return None
-    if semver.compare(collection_version.version, last_highest.version) > 0:
+    if Version(collection_version.version) > Version(last_highest.version):
         last_highest.is_highest = False
         collection_version.is_highest = True
         last_highest.save()
@@ -277,6 +295,7 @@ class CollectionSyncFirstStage(Stage):
         super().__init__()
         self.remote = remote
         self.collection_info = parse_collections_requirements_file(remote.requirements_file)
+        self.deprecations = Q()
 
         # Interpret download policy
         self.deferred_download = self.remote.policy != Remote.IMMEDIATE
@@ -315,10 +334,7 @@ class CollectionSyncFirstStage(Stage):
                     deferred_download=self.deferred_download,
                 )
 
-                extradata = dict(
-                    docs_blob_url=metadata["docs_blob_url"],
-                    deprecated=metadata["deprecated"],
-                )
+                extradata = dict(docs_blob_url=metadata["docs_blob_url"])
 
                 d_content = DeclarativeContent(
                     content=collection_version,
@@ -423,13 +439,6 @@ class CollectionSyncFirstStage(Stage):
             else:
                 return path_or_url
 
-        def _add_collection_level_metadata(data, additional_metadata):
-            """Additional metadata at collection level to be sent through stages."""
-            name = data["collection"]["name"]
-            namespace = data["namespace"]["name"]
-            metadata = additional_metadata.get(f"{namespace}_{name}", {})
-            data["deprecated"] = metadata.get("deprecated")
-
         def _add_collection_version_level_metadata(data, additional_metadata):
             """Additional metadata at collection version level to be sent through stages."""
             metadata = additional_metadata.get(_build_url(data["href"]), {})
@@ -466,9 +475,7 @@ class CollectionSyncFirstStage(Stage):
                                 namespace = result["namespace"]["name"]  # api v3
                             except TypeError:
                                 namespace = result["namespace"]  # api v2
-                            additional_metadata[f"{namespace}_{name}"] = {
-                                "deprecated": result["deprecated"]
-                            }
+                            self.deprecations |= Q(namespace=namespace, name=name)
 
                         if result.get("versions_url"):
                             versions_url = _build_url(result.get("versions_url"))
@@ -478,12 +485,12 @@ class CollectionSyncFirstStage(Stage):
                         if result.get("version") and not download_url:
                             version_url = _build_url(result["href"])
                             not_done.update([remote.get_downloader(url=version_url).run()])
-                            additional_metadata[version_url] = {
-                                "docs_blob_url": f"{version_url}docs-blob/"
-                            }
+                            if self.api_version > 2:
+                                additional_metadata[version_url] = {
+                                    "docs_blob_url": f"{version_url}docs-blob/"
+                                }
 
                         if download_url:
-                            _add_collection_level_metadata(data, additional_metadata)
                             _add_collection_version_level_metadata(data, additional_metadata)
                             yield data
 
@@ -507,7 +514,8 @@ class DocsBlobDownloader(ArtifactDownloader):
             The number of downloads
         """
         downloaded = 0
-        if d_content.d_artifacts:
+        content_already_saved = not d_content.content._state.adding
+        if not content_already_saved and d_content.d_artifacts:
             remote = d_content.d_artifacts[0].remote
             docs_blob = d_content.extra_data.get("docs_blob_url")
             if docs_blob:
@@ -548,8 +556,6 @@ class CollectionContentSaver(ContentSaver):
                 :class:`~pulpcore.plugin.stages.DeclarativeContent` objects to be saved.
 
         """
-        to_deprecate = []
-
         for d_content in batch:
             if d_content is None:
                 continue
@@ -563,16 +569,6 @@ class CollectionContentSaver(ContentSaver):
 
             d_content.content.collection = collection
 
-            if d_content.extra_data.get("deprecated"):
-                to_deprecate.append(
-                    AnsibleCollectionDeprecated(
-                        repository_version=self.repository_version, collection=collection
-                    )
-                )
-
-        if to_deprecate:
-            AnsibleCollectionDeprecated.objects.bulk_create(to_deprecate, ignore_conflicts=True)
-
     async def _post_save(self, batch):
         """
         Save a batch of CollectionVersion, Tag objects.
@@ -597,7 +593,15 @@ class CollectionContentSaver(ContentSaver):
                     fileobj=artifact_file, mode="r"
                 ) as tar:
                     log.info(_("Reading MANIFEST.json from {path}").format(path=artifact.file.name))
-                    file_obj = tar.extractfile("MANIFEST.json")
+                    for manifest in ["MANIFEST.json", "./MANIFEST.json"]:
+                        try:
+                            file_obj = tar.extractfile(manifest)
+                        except KeyError:
+                            file_obj = None
+                        else:
+                            break
+                    if not file_obj:
+                        raise FileNotFoundError("MANIFEST.json not found")
                     manifest_data = json.load(file_obj)
                     info = manifest_data["collection_info"]
 
